@@ -155,7 +155,7 @@ class Crp:
 
 
 
-    def getFeaturesMatrix(train_df,org_df,timeFlag,items_dataset):
+    def getFeaturesMatrix(self,train_df,org_df,timeFlag,items_dataset):
         """
         Params:
             train_df -> train timeframe dataframe
